<p class="logo">
  <a href="{{ pathto(root_doc) }}">
    <img class="logo" src="{{ pathto('_static/requests-sidebar.png', 1) }}" alt="{{ _('Requests logo') }}" />
  </a>
</p>

<p>
  <iframe src="https://ghbtns.com/github-btn.html?user=psf&repo=requests&type=watch&count=true&size=large"
    allowtransparency="true" frameborder="0" scrolling="0" width="200px" height="35px"></iframe>
</p>

<p>
  {{ _('Requests is an elegant and simple HTTP library for Python, built for human beings.') }}
</p>

<h3>{{ _('Useful Links') }}</h3>
<ul>
  <li><a href="{{ pathto('user/quickstart') }}">{{ _('Quickstart') }}</a></li>
  <li><a href="{{ pathto('user/advanced') }}">{{ _('Advanced Usage') }}</a></li>
  <li><a href="{{ pathto('api') }}">{{ _('API Reference') }}</a></li>
  <li><a href="{{ pathto('community/updates') + '#release-history' }}">{{ _('Release History') }}</a></li>
  <li><a href="{{ pathto('dev/contributing') }}">{{ _('Contributors Guide') }}</a></li>

  <p></p>

  <li><a href="{{ pathto('community/recommended') }}">{{ _('Recommended Packages and Extensions') }}</a></li>

  <p></p>

  <li><a href="https://github.com/psf/requests">{{ _('Requests @ GitHub') }}</a></li>
  <li><a href="https://pypi.org/project/requests/">{{ _('Requests @ PyPI') }}</a></li>
  <li><a href="https://github.com/psf/requests/issues">{{ _('Issue Tracker') }}</a></li>
</ul>
